@@ -6,9 +6,6 @@ from tqatest.app.core.config import MODEL_NAME, MODEL_PATH, MODEL_ID
 from loguru import logger
 from tqatest.ml.libs import annhub
 
-MODEL_NAME = "TrainedModel_c++.ann"
-MODEL_PATH = "ml/model/"
-MODEL_ID = 5122020
 
 class MachineLearningModel(object):
     def __init__(self) -> None:
